---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

### The problem

A clear and concise description of the bug.  If known, explain why you believe the problem is within this library.

Error message(s):

```bash
# Include any error messages if available.
```

### To Reproduce

1. What indicator and parameter arguments were used?
2. Attach the historical quotes you used (as CSV or Excel file)
